@@ -70,7 +70,7 @@ def load_neuron_files(neuron_num,file_num_list,show_print=False,data_dir=None):
     """
     This function loads and returns data specified by the user.  
     
-    :param neuron_num: nnumber of neuron we want to load, integer from 1 to 12.
+    :param neuron_num: number of neuron we want to load, integer from 1 to 12.
     :param file_num_list: list of indices ranging from and including 1 to 99 corresponding to specific stim/sweep files we want to load.
     :param show_print: bool determining whether we print the stim files loaded (the corresponding voltage files are also loaded, just not printed).
     :keyword data_dir: path of DataTextFiles directory 
