@@ -19,21 +19,19 @@ def easy_test():
     model = gLIF_model()
     
     # load data 
-    (file_id_list,X_list,Y_list,dt) = load_neuron_data(1,input_type="noise_only",max_file_ct=4) 
+    (file_id_list,X_list,Y_list,dt) = load_neuron_data(neuron_num=1,input_type="noise_only",max_file_ct=4) 
     
     # fit model
     model.fit(X_list, Y_list, dt)
     
-    # predict data via model
-    Y_pred_list = model.predict(X_list, dt)
+    # predict voltage traces via model
+    Y_pred_list = model.predict(X_list)
     
     # plot predicted data vs actual data for the first voltage trace in X_list
     t_arr = dt * np.arange(len(Y_pred_list[0]))
-            
     pylab.plot(t_arr,Y_list[0],color='blue',label='True voltage')
     pylab.plot(t_arr,Y_pred_list[0],color='green',label='Predicted voltage')
     pylab.legend()
-    
     pylab.xlabel("Time (s)")
     pylab.ylabel("Voltage (mV)")
     pylab.title("Response to Input Current")
